from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.health_status import HealthStatus
from ..types import UNSET, Unset
from dateutil.parser import isoparse
from typing import cast
import datetime

if TYPE_CHECKING:
  from ..models.health_extensions import HealthExtensions
  from ..models.health_checks_item import HealthChecksItem





T = TypeVar("T", bound="Health")



@_attrs_define
class Health:
    """ 
        Attributes:
            status (HealthStatus):
            time (datetime.datetime):
            checks (list[HealthChecksItem] | Unset):
            extensions (HealthExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
     """

    status: HealthStatus
    time: datetime.datetime
    checks: list[HealthChecksItem] | Unset = UNSET
    extensions: HealthExtensions | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.health_extensions import HealthExtensions
        from ..models.health_checks_item import HealthChecksItem
        status = self.status.value

        time = self.time.isoformat()

        checks: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.checks, Unset):
            checks = []
            for checks_item_data in self.checks:
                checks_item = checks_item_data.to_dict()
                checks.append(checks_item)



        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "status": status,
            "time": time,
        })
        if checks is not UNSET:
            field_dict["checks"] = checks
        if extensions is not UNSET:
            field_dict["extensions"] = extensions

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.health_extensions import HealthExtensions
        from ..models.health_checks_item import HealthChecksItem
        d = dict(src_dict)
        status = HealthStatus(d.pop("status"))




        time = isoparse(d.pop("time"))




        _checks = d.pop("checks", UNSET)
        checks: list[HealthChecksItem] | Unset = UNSET
        if _checks is not UNSET:
            checks = []
            for checks_item_data in _checks:
                checks_item = HealthChecksItem.from_dict(checks_item_data)



                checks.append(checks_item)


        _extensions = d.pop("extensions", UNSET)
        extensions: HealthExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = HealthExtensions.from_dict(_extensions)




        health = cls(
            status=status,
            time=time,
            checks=checks,
            extensions=extensions,
        )

        return health




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.trace_response_trace_event_level import TraceResponseTraceEventLevel
from ..types import UNSET, Unset
from dateutil.parser import isoparse
from typing import cast
import datetime

if TYPE_CHECKING:
  from ..models.trace_response_trace_event_extensions import TraceResponseTraceEventExtensions
  from ..models.trace_response_trace_event_data import TraceResponseTraceEventData





T = TypeVar("T", bound="TraceResponseTraceEvent")



@_attrs_define
class TraceResponseTraceEvent:
    """ 
        Attributes:
            level (TraceResponseTraceEventLevel):
            run_id (str):
            seq (int):
            time (datetime.datetime):
            type_ (str):
            data (TraceResponseTraceEventData | Unset):
            extensions (TraceResponseTraceEventExtensions | Unset): Optional vendor extension map. Keys must be namespaced
                as <reverse_dns_or_org>.<key>.
     """

    level: TraceResponseTraceEventLevel
    run_id: str
    seq: int
    time: datetime.datetime
    type_: str
    data: TraceResponseTraceEventData | Unset = UNSET
    extensions: TraceResponseTraceEventExtensions | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.trace_response_trace_event_extensions import TraceResponseTraceEventExtensions
        from ..models.trace_response_trace_event_data import TraceResponseTraceEventData
        level = self.level.value

        run_id = self.run_id

        seq = self.seq

        time = self.time.isoformat()

        type_ = self.type_

        data: dict[str, Any] | Unset = UNSET
        if not isinstance(self.data, Unset):
            data = self.data.to_dict()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "level": level,
            "run_id": run_id,
            "seq": seq,
            "time": time,
            "type": type_,
        })
        if data is not UNSET:
            field_dict["data"] = data
        if extensions is not UNSET:
            field_dict["extensions"] = extensions

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.trace_response_trace_event_extensions import TraceResponseTraceEventExtensions
        from ..models.trace_response_trace_event_data import TraceResponseTraceEventData
        d = dict(src_dict)
        level = TraceResponseTraceEventLevel(d.pop("level"))




        run_id = d.pop("run_id")

        seq = d.pop("seq")

        time = isoparse(d.pop("time"))




        type_ = d.pop("type")

        _data = d.pop("data", UNSET)
        data: TraceResponseTraceEventData | Unset
        if isinstance(_data,  Unset):
            data = UNSET
        else:
            data = TraceResponseTraceEventData.from_dict(_data)




        _extensions = d.pop("extensions", UNSET)
        extensions: TraceResponseTraceEventExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = TraceResponseTraceEventExtensions.from_dict(_extensions)




        trace_response_trace_event = cls(
            level=level,
            run_id=run_id,
            seq=seq,
            time=time,
            type_=type_,
            data=data,
            extensions=extensions,
        )

        return trace_response_trace_event




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.instance_create_response_extensions import InstanceCreateResponseExtensions
  from ..models.instance_create_response_runtime_instance import InstanceCreateResponseRuntimeInstance





T = TypeVar("T", bound="InstanceCreateResponse")



@_attrs_define
class InstanceCreateResponse:
    """ 
        Attributes:
            instances (list[InstanceCreateResponseRuntimeInstance]):
            extensions (InstanceCreateResponseExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
     """

    instances: list[InstanceCreateResponseRuntimeInstance]
    extensions: InstanceCreateResponseExtensions | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.instance_create_response_extensions import InstanceCreateResponseExtensions
        from ..models.instance_create_response_runtime_instance import InstanceCreateResponseRuntimeInstance
        instances = []
        for instances_item_data in self.instances:
            instances_item = instances_item_data.to_dict()
            instances.append(instances_item)



        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "instances": instances,
        })
        if extensions is not UNSET:
            field_dict["extensions"] = extensions

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.instance_create_response_extensions import InstanceCreateResponseExtensions
        from ..models.instance_create_response_runtime_instance import InstanceCreateResponseRuntimeInstance
        d = dict(src_dict)
        instances = []
        _instances = d.pop("instances")
        for instances_item_data in (_instances):
            instances_item = InstanceCreateResponseRuntimeInstance.from_dict(instances_item_data)



            instances.append(instances_item)


        _extensions = d.pop("extensions", UNSET)
        extensions: InstanceCreateResponseExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = InstanceCreateResponseExtensions.from_dict(_extensions)




        instance_create_response = cls(
            instances=instances,
            extensions=extensions,
        )

        return instance_create_response




"""ARP Tool Registry API facade (preferred) + low-level client package."""

from __future__ import annotations

from importlib import import_module
from typing import TYPE_CHECKING, Any

__all__ = [
    'ArpApiError',
    'GetToolRequest',
    'Health',
    'HealthRequest',
    'InvokeToolRequest',
    'ListToolsRequest',
    'ToolDefinition',
    'ToolInvocationResult',
    'ToolRegistryClient',
    'VersionInfo',
    'VersionRequest',
]

_EXPORT_MAP: dict[str, str] = {
    'GetToolRequest': '.sdk',
    'Health': '.models',
    'HealthRequest': '.sdk',
    'InvokeToolRequest': '.sdk',
    'ListToolsRequest': '.sdk',
    'ToolDefinition': '.models',
    'ToolInvocationResult': '.models',
    'ToolRegistryClient': '.sdk',
    'VersionInfo': '.models',
    'VersionRequest': '.sdk',
}

if TYPE_CHECKING:
    from arp_sdk.errors import ArpApiError
    from .sdk import GetToolRequest, HealthRequest, InvokeToolRequest, ListToolsRequest, ToolRegistryClient, VersionRequest
    from .models import Health, ToolDefinition, ToolInvocationResult, VersionInfo

def __getattr__(name: str) -> Any:
    if name == "ArpApiError":
        from arp_sdk.errors import ArpApiError as _ArpApiError

        return _ArpApiError
    module = _EXPORT_MAP.get(name)
    if module is None:
        raise AttributeError(name)
    if module.startswith("."):
        return getattr(import_module(module, __name__), name)
    return getattr(import_module(module), name)




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.instance_register_response_extensions import InstanceRegisterResponseExtensions
  from ..models.instance_register_response_runtime_instance import InstanceRegisterResponseRuntimeInstance





T = TypeVar("T", bound="InstanceRegisterResponse")



@_attrs_define
class InstanceRegisterResponse:
    """ 
        Attributes:
            instance (InstanceRegisterResponseRuntimeInstance):
            extensions (InstanceRegisterResponseExtensions | Unset): Optional vendor extension map. Keys must be namespaced
                as <reverse_dns_or_org>.<key>.
     """

    instance: InstanceRegisterResponseRuntimeInstance
    extensions: InstanceRegisterResponseExtensions | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.instance_register_response_extensions import InstanceRegisterResponseExtensions
        from ..models.instance_register_response_runtime_instance import InstanceRegisterResponseRuntimeInstance
        instance = self.instance.to_dict()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "instance": instance,
        })
        if extensions is not UNSET:
            field_dict["extensions"] = extensions

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.instance_register_response_extensions import InstanceRegisterResponseExtensions
        from ..models.instance_register_response_runtime_instance import InstanceRegisterResponseRuntimeInstance
        d = dict(src_dict)
        instance = InstanceRegisterResponseRuntimeInstance.from_dict(d.pop("instance"))




        _extensions = d.pop("extensions", UNSET)
        extensions: InstanceRegisterResponseExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = InstanceRegisterResponseExtensions.from_dict(_extensions)




        instance_register_response = cls(
            instance=instance,
            extensions=extensions,
        )

        return instance_register_response




"""ARP Runtime API facade (preferred) + low-level client package."""

from __future__ import annotations

from importlib import import_module
from typing import TYPE_CHECKING, Any

__all__ = [
    'ArpApiError',
    'CancelRunRequest',
    'CreateRunRequest',
    'GetRunResultRequest',
    'GetRunStatusRequest',
    'Health',
    'HealthRequest',
    'RunRequest',
    'RunResult',
    'RunStatus',
    'RuntimeClient',
    'StreamRunEventsRequest',
    'VersionInfo',
    'VersionRequest',
]

_EXPORT_MAP: dict[str, str] = {
    'CancelRunRequest': '.sdk',
    'CreateRunRequest': '.sdk',
    'GetRunResultRequest': '.sdk',
    'GetRunStatusRequest': '.sdk',
    'Health': '.models',
    'HealthRequest': '.sdk',
    'RunRequest': '.models',
    'RunResult': '.models',
    'RunStatus': '.models',
    'RuntimeClient': '.sdk',
    'StreamRunEventsRequest': '.sdk',
    'VersionInfo': '.models',
    'VersionRequest': '.sdk',
}

if TYPE_CHECKING:
    from arp_sdk.errors import ArpApiError
    from .sdk import CancelRunRequest, CreateRunRequest, GetRunResultRequest, GetRunStatusRequest, HealthRequest, RuntimeClient, StreamRunEventsRequest, VersionRequest
    from .models import Health, RunRequest, RunResult, RunStatus, VersionInfo

def __getattr__(name: str) -> Any:
    if name == "ArpApiError":
        from arp_sdk.errors import ArpApiError as _ArpApiError

        return _ArpApiError
    module = _EXPORT_MAP.get(name)
    if module is None:
        raise AttributeError(name)
    if module.startswith("."):
        return getattr(import_module(module, __name__), name)
    return getattr(import_module(module), name)

